@@ -16,22 +16,25 @@ def register():
         CategoryDocument,
         DocumentLocation,
         DocumentRecord,
+        DocumentLending,
         Document,
         Communication,
         CommunicationAttachment,
         DocumentConfiguration,
-        DocumentLending,
         DocumentLendingDocument,
         DocumentCommunicationEmployee,
         CommunicationLetter,
         DocumentRecordInventoryStart,
         SearchDocumentFileStart,
+        TRDStart,
         module='document', type_='model')
     Pool.register(
         CommunicationLetterReport,
         DocumentRecordInventoryReport,
+        TRDReport,
         module='document', type_='report')
     Pool.register(
         DocumentRecordInventory,
         SearchDocumentFile,
+        TRD,
         module='document', type_='wizard')
